##
##  Start log
mylog = file("log_checker_cnvs.txt", open = "wt")
sink(mylog)
Sys.time()
sessionInfo()


## DESCRIPTION
## R code for exploratory analysis of locus from Genomestrip CNV pipeline output.
## Summary data generated by GATK variantsToTable wpgilks@gmail.com @wpgilks @gwas_lit


## Load packages

package.list = c('tidyr', 'dplyr', 'ggplot2')
  new.packages = package.list[!(package.list %in% installed.packages()[,"Package"])]
  if(length(new.packages)) install.packages(new.packages)
  rm (package.list, new.packages)

library(ggplot2)
library(tidyr)
library(dplyr)


## Load data
  
qc.table.in = read.delim(file = "summary_data/filtered.goodS.lhm_gs.cnvs.raw.vcf.qc.tbl")

head (qc.table.in)


### Do some data normalisation stuff and calculate minor allele frequency groups.

df = qc.table.in %>%
  mutate (Mb = POS / 1e+06) %>%
  mutate (len = GCLENGTH /1000) %>%
  mutate (rt.len = sqrt(len)) %>%
  mutate (qual = GSCNQUAL / 1000) %>%
  mutate (gcount = HOM.REF + HET + HOM.VAR + NO.CALL) %>%
  mutate (g2 = HET + (2*HOM.VAR)) %>%
  mutate (min.ac = pmin (HOM.REF, g2)) %>%
  mutate (maj.ac = pmax (HOM.REF, g2)) %>%
  mutate (MAF = min.ac / gcount) %>%
  mutate (rMAF = round(MAF, digits = 1))

head (df)



## Plot HET count across genome, point size by event length, colour by cluster separation.

gplot = ggplot (filter(df, CHROM!="chr4"), aes (Mb, HET, size = rt.len,
  colour = sqrt(GSCLUSTERSEP))) +
  geom_point() +
  theme_bw(base_size = 8) +
  labs (title = "filtered gs cnv dmel") +
  facet_grid(GSCNCATEGORY~CHROM, scales = "free_x", space = "free_x", "switch=x") +
  theme (strip.background = element_rect(colour = "white", fill = "white"))
gplot



## Reformat data as long.

plot.data = df %>%
  select (-c(AF, AN, AC, GLALTSUM, GLHETSUM, GSNNONREF, GCLENGTH, GSCNQUAL,  gcount, g2, min.ac, maj.ac, NO.CALL, len)) %>%
  gather (key = metric, value = value, -c(CHROM, ID, POS, MAF, rMAF, GSCNCATEGORY, HOM.REF, HET, HOM.VAR, Mb))



## make labels for plot facets.

flabs = as_labeller ( c (`DUP`="Duplication",  `MIXED`="mixed",  `DEL`="Deletion",
                         `GCFRACTION`="%GC",  `GSCLUSTERSEP`="Cluster sep.", `rt.len`="sqrt Length(Kb)",
                         `qual`= "quality x10^3") )


##  Plot metrics distributions grouped by MAF and type.

plot = ggplot (plot.data, aes (value, colour =  as.factor(rMAF), fill = as.factor(rMAF))) +
    geom_histogram() +
    theme_bw(base_size = 8) +
    labs(title = "filtered GS CNV QC", x = "", y = "") +
    guides(fill = guide_legend (title = "MAF")) +
    guides(colour  = guide_legend (title = "MAF")) +
      scale_fill_manual(values = c("0"="black", "0.1"="blue", "0.2"="green",
    "0.3"="yellow", "0.4"="orange", "0.5=red", "0.6"="purple")) +
    scale_colour_manual(values = c("0"="black", "0.1"="blue", "0.2"="green",
    "0.3"="yellow", "0.4"="orange", "0.5=red", "0.6"="purple")) +
    facet_grid(GSCNCATEGORY~metric, scales = "free", switch = "both", labeller = flabs)   +
    theme (
      strip.background = element_rect(colour = "white", fill = "white"),
      strip.text.y = element_text(angle=180),
      legend.position = c(.9,.9), legend.key.width = unit(.2, "cm"), legend.key.height = unit(.2, "cm"))
plot


## End stuff
ls()
rm(list=ls())
sessionInfo()
sink()
unlink("log_checker_cnvs.txt")
###
###